sites = {
    "kattis": "https://open.kattis.com/problems",
    "leetcode": "https://leetcode.com/problems",
    "cses": "https://cses.fi/problemset/task",
    "codeforces": "https://codeforces.com/problemset/problem",
    "project euler": "https://projecteuler.net/problem=",
    "dmoj": "https://dmoj.ca/problem"
}
