languages = {
    ".py": "Python",
    ".cpp": "C++",
    ".hs": "Haskell",
    ".js": "Javascript",
    ".rs": "Rust",
    ".c": "C",
    ".ts": "Typescript",
    ".cs": "C#",
    ".go": "Go",
    ".java": "Java",
    ".ml": "OCaml",
    ".php": "PHP",
    ".rb": "Ruby",
    ".m": "Objective C"
}
